@@ -47,6 +47,11 @@ def get_synchronization_tasks(object_name):
              {'name': 'create_binhost_data',
               'method': Object('create_binhost_data()')
              },
+             {
+              'name': 'check_if_update_by_branch',
+              'method': Object('turn_off_migration_if_needed()'),
+              'condition': lambda Get, GetBool: (Get('cl_check_update_level')  == 'on')
+             },
              # проверить валиден ли текущий хост
              {'name': 'check_current_binhost',
               'message': __("Checking current binhost"),
